package com.dayou.controller;

import com.dayou.common.RestResponse;
import com.dayou.dto.PersonalFacePriceQueryDTO;
import com.dayou.service.IPersonalFacePriceService;
import com.dayou.vo.DayouPersonalPriceVO;
import com.dayou.vo.ExternalFacePriceVO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 个贷口估
 */
@RestController
@RequestMapping("personalFacePrice")
@Slf4j
public class PersonalFacePriceController extends BaseController {

    @Autowired
    private IPersonalFacePriceService personalFacePriceService;

    /**
     * 查询大友个贷历史评估价格(地址)
     * @param facePriceQuery
     * @return
     */
    @PostMapping("/dy/location/price")
    public RestResponse<List<DayouPersonalPriceVO>> personalPriceByLocation(@RequestBody PersonalFacePriceQueryDTO facePriceQuery) {
        List<DayouPersonalPriceVO> ret = personalFacePriceService.personalPriceByLocation(facePriceQuery);
        return RestResponse.success(ret);
    }

    /**
     * 查询大友个贷历史评估价格(小区名字)
     * @param facePriceQuery
     * @return
     */
    @PostMapping("/dy/community/price")
    public RestResponse<List<DayouPersonalPriceVO>> personalPriceByCommunity(@RequestBody PersonalFacePriceQueryDTO facePriceQuery) {
        List<DayouPersonalPriceVO> ret = personalFacePriceService.personalPriceByCommunity(facePriceQuery);
        return RestResponse.success(ret);
    }

    /**
     * 查询外部数据价格（地址）
     * @param facePriceQuery
     * @return
     */
    @PostMapping("/external/location/price")
    public RestResponse<ExternalFacePriceVO> externalPriceByLocation(@RequestBody PersonalFacePriceQueryDTO facePriceQuery) {
        ExternalFacePriceVO ret = personalFacePriceService.externalPriceByLocation(facePriceQuery);
        return RestResponse.success(ret);
    }

    /**
     * 查询外部数据价格（小区名字）
     * @param facePriceQuery
     * @return
     */
    @PostMapping("/external/community/price")
    public RestResponse<ExternalFacePriceVO> externalPersonalPriceByCommunity(@RequestBody PersonalFacePriceQueryDTO facePriceQuery) {
        ExternalFacePriceVO ret = personalFacePriceService.externalPersonalPriceByCommunity(facePriceQuery);
        return RestResponse.success(ret);
    }
}
